@@ -6,7 +6,7 @@ use strict;
 use utf8;
 use warnings;
 
-our $VERSION = "2.004";
+our $VERSION = "2.100";
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -25,34 +25,40 @@ our %EXPORT_TAGS = (
     ],
   '_var' => [
       '$IDNA_PREFIX',
-      '$IDNA_DOT',
-      '$IDNA_ATSIGN',
+      'IsIDNADot',
+      'IsIDNAAtsign',
     ]
 );
 Exporter::export_ok_tags(keys %EXPORT_TAGS);
 
 use Net::IDN::Punycode 1 ();
 
-our ($IDNA_PREFIX,$IDNA_DOT,$IDNA_ATSIGN);
-*IDNA_PREFIX 	= \'xn--';
-*IDNA_DOT	= \qr/[\.。．｡]/;
-*IDNA_ATSIGN	= \qr/[\@＠]/;
+our $IDNA_PREFIX = 'xn--';
+sub IsIDNADot 	{ "002E\n3002\nFF0E\nFF61" }
+sub IsIDNAAtsign{ "0040\nFE6B\nFF20" }
 
 require Net::IDN::UTS46; # after declaration of vars!
 
 sub to_ascii {
   my($label,%param) = @_;
-  croak 'Invalid label' if $label =~ m/$IDNA_DOT/o;
-  eval { $label = Net::IDN::UTS46::to_ascii(@_) };
-  die $@ if $@ and ($label =~ m/\P{ASCII}/);
+  croak 'Invalid label' if $label =~ m/\p{IsIDNADot}/o;
+
+  if($label =~ m/\P{ASCII}/o) {
+    $label = Net::IDN::UTS46::to_ascii(@_);
+  } else {
+    croak 'label empty' if length($label) < 1;
+    croak 'label too long' if length($label) > 63;
+  }
   return $label;
 }
 
 sub to_unicode {
   my($label,%param) = @_;
-  croak 'Invalid label' if $label =~ m/$IDNA_DOT/o;
-  eval { $label = Net::IDN::UTS46::to_unicode(@_) };
-  die $@ if $@ and ($label =~ m/\P{ASCII}/);
+  croak 'Invalid label' if $label =~ m/\p{IsIDNADot}/o;
+
+  if($label =~ m/\P{ASCII}|^$IDNA_PREFIX/o) {
+    $label = Net::IDN::UTS46::to_unicode(@_);
+  }
   return $label;
 }
 
@@ -63,7 +69,7 @@ sub _domain {
   my $even_odd = 1;
   return join '',
     map { $even_odd++ % 2 ? $to_function->($_, %param) : $ascii ? '.' : $_ }
-      split /($IDNA_DOT)/o, $domain;
+      split /(\p{IsIDNADot})/o, $domain;
 }
 
 sub _email {
@@ -71,12 +77,12 @@ sub _email {
   return $email if !defined($email) || $email eq '';
 
   $email =~ m/^(
-	(?(?!$IDNA_ATSIGN|").|(?!))+
+	(?(?!\p{IsIDNAAtsign}|").|(?!))+
 	|
 	"(?:(?:[^"]|\\.)*[^\\])?"
       )
       (?:
-	($IDNA_ATSIGN)
+	(\p{IsIDNAAtsign})
    	(?:([^\[\]]*)|(\[.*\]))?
       )?$/xo || croak "Invalid email address";
   my($local_part,$at,$domain,$domain_literal) = ($1,$2,$3);
@@ -128,6 +134,13 @@ the ASCII characters already allowed in so-called host names today
 Use this module if you just want to convert domain names (or email addresses),
 using whatever IDNA standard is the best choice at the moment.
 
+=head1 UNICODE VERSION
+
+To convert labels correctly between Unicode and ASCII, each character in the
+label must be present in the Unicode version supported by your perl.
+Consequently, this module will refuse to convert labels with new Unicode
+characters on older perl versions (see below).
+
 =head1 FUNCTIONS
 
 By default, this module does not export any subroutines. You may
@@ -152,12 +165,17 @@ This function takes the following optional parameters (C<%param>):
 
 =item AllowUnassigned
 
-(boolean) If set to a true value, unassigned code points in the label are
-allowed. While maximizing the compatibility with future versions of Unicode
-and/or IDNA, this option is also dangerous: Characters added in future versions
-of Unicode might have properties that affect the conversion; you might
-therefore end up with a conversion that is incompatible with later standards.
-Therefore, set this to false unless you know what you are doing.
+(boolean) If set to a true value, code points that are unassigned in the
+Unicode version supported by your perl are allowed. This is an extension over
+UTS #46.
+
+While this increases the number of labels that can be converted successfully
+(especially on older perls) and may thus maximizes the compatibility with
+domain names created under future versions of Unicode, it also introduces the
+risk of incorrect conversions.  Characters added in later versions of Unicode
+might have properties that affect the conversion; if these properties are not
+known on your version of perl, you might therefore end up with an incorrect
+conversion.
 
 The default is false.
 
@@ -207,8 +225,8 @@ This function takes the following optional parameters (C<%param>):
 
 =item UseSTD3ASCIIRules
 
-See C<to_unicode> above. Please note that there is no C<TransitionalProcessing>
-for C<to_unicode>.
+See C<to_unicode> above. Please note that there is no need for
+C<TransitionalProcessing> for C<to_unicode>.
 
 =back
 
@@ -217,7 +235,7 @@ domain names). Use C<domain_to_unicode> instead.
 
 =item domain_to_ascii( $label, %param )
 
-Converts all labels of the hostname C<$domain> (with labels seperated by dots)
+Converts all labels of the hostname C<$domain> (with labels separated by dots)
 to ASCII (using C<to_ascii>). Will throw an exception on invalid input.
 
 This function takes the following optional parameters (C<%param>):
@@ -246,7 +264,7 @@ ideographic full stop).
 
 =item domain_to_unicode( $domain, %param )
 
-Converts all labels of the hostname C<$domain> (with labels seperated by dots)
+Converts all labels of the hostname C<$domain> (with labels separated by dots)
 to Unicode. Will throw an exception on invalid input.
 
 This function takes the same optional parameters as C<domain_to_ascii>,
@@ -283,7 +301,8 @@ conversion for the local-part, should one be standardized.
 
 This function will convert the at sign to ASCII, i.e. to U+0040 (commercial
 at), as well as label separators.  The follwing characters are recognized as at
-signs: U+0040 (commercial at), U+FF20 (fullwidth commercial at).
+signs: U+0040 (commercial at), U+FE6B (small commercial at) and U+FF20
+(fullwidth commercial at).
 
 =item email_to_unicode( $email, %param )
 
@@ -299,7 +318,8 @@ from ASCII for the local-part, should one be standardized.
 
 This function will preserve the original version of at signs (and label
 separators). The follwing characters are recognized as at signs: U+0040
-(commercial at), U+FF20 (fullwidth commercial at).
+(commercial at), U+FE6B (small commercial at) and U+FF20 (fullwidth commercial
+at).
 
 =back
 
@@ -309,7 +329,7 @@ Claus FE<auml>rber <CFAERBER@cpan.org>
 
 =head1 LICENSE
 
-Copyright 2007-2012 Claus FE<auml>rber.
+Copyright 2007-2013 Claus FE<auml>rber.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
