@@ -8,7 +8,7 @@ use warnings;
 
 use Exporter;
 
-our $VERSION = "2.499_20180929";
+our $VERSION = "1.101";
 $VERSION = eval $VERSION;
 
 our @ISA = qw(Exporter);
@@ -16,7 +16,7 @@ our @EXPORT = ();
 our @EXPORT_OK = ();
 our %EXPORT_TAGS = ( 'all'  => [ qw(encode_punycode decode_punycode) ], );
 Exporter::export_ok_tags(keys %EXPORT_TAGS);
-our $_NO_XS;
+our $_NO_XS = undef;
 
 eval { 
   die if $_NO_XS;
@@ -44,32 +44,27 @@ Net::IDN::Punycode - A Bootstring encoding of Unicode for IDNA (S<RFC 3492>)
 
 =head1 DESCRIPTION
 
-This module implements the Punycode encoding, and only the Punycode encoding.
+This module implements the Punycode encoding. Punycode is an instance of a more
+general algorithm called Bootstring, which allows strings composed from a small
+set of "basic" code points to uniquely represent any string of code points
+drawn from a larger set. Punycode is Bootstring with particular parameter
+values appropriate for IDNA.
 
-This module does not implement any other steps required for converting
-internationalized domain names (IDNs) to and from ASCII. In particular, it does
-not do any string preparation as specified by I<Nameprep>/I<IDNA2008>/I<PRECIS>
-and does not add nor remove the ACE prefix (C<xn-->). Thus, use
-L<Net::IDN::Encode> if you want to convert domain names.
-
-Punycode is an instance of a more general algorithm called Bootstring, which
-allows strings composed from a small set of "basic" code points to uniquely
-represent any string of code points drawn from a larger set. Punycode is
-Bootstring with particular parameter values appropriate for IDNA.
+Note that this module does not do any string preparation as specified by
+I<Nameprep>/I<IDNA2008>/I<PRECIS> and does not add nor remove the ACE prefix
+(C<xn-->). Thus, use L<Net::IDN::Encode> if you want to convert domain names.
 
 =head1 WARNING
 
-You may be tempted to use this module directly and add/remove the ACE prefix
-(C<xn-->) in your code for performance reasons. Usually, this is not a good
-idea.  If you convert domain labels (or other strings) without proper
-preparation, you may end up with an ASCII encoding that is not interoperable or
-even poses security issues due to spoofing.
+Usually, it is not a good idea to use this module directly. If you convert
+domain labels (or other strings) without proper prepration, you may end up with
+an ASCII encoding that is not interoperable or even poses security issues due
+to spoofing.
 
 Even if you think that your domain names are valid and already mapped to the
-correct form, this may not be true. For example, some environments might
-automatically convert your perfectly valid domain names to a different but
-equivalent Unicode normalization form (e.g., NFD instead of NFC), which already
-breaks IDNA.
+correct form, you might be fooled by different Unicode normalization forms (for
+example, some environments might automatically convert your data to NFD, which
+breaks IDNA).
 
 =head1 FUNCTIONS
 
@@ -104,7 +99,7 @@ Claus FE<auml>rber E<lt>CFAERBER@cpan.orgE<gt> (versions 1.000 and higher)
 
 Copyright 2002-2004 Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>
 
-Copyright 2007-2014 Claus FE<auml>rber E<lt>CFAERBER@cpan.orgE<gt>
+Copyright 2007-2013 Claus FE<auml>rber E<lt>CFAERBER@cpan.orgE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
